package com.persagy.account.config;

import org.springframework.amqp.core.TopicExchange;
import org.springframework.amqp.rabbit.config.SimpleRabbitListenerContainerFactory;
import org.springframework.amqp.rabbit.connection.ConnectionFactory;
import org.springframework.amqp.rabbit.core.RabbitAdmin;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.amqp.support.converter.Jackson2JsonMessageConverter;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Configurable;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Component;

import com.persagy.account.mq.CommonConfirmCallback;

/**
 * 采用jackson序列号消息内容
 * @version 
 * @description 
 * @company persagy
 * @author zhangqiankun
 * @since 2020年9月15日:	下午2:09:17
 */
@Component
public class RabbitMQConfig {
	
	@Autowired
    private RabbitAdmin rabbitAdmin;
	
	@Autowired
	private ApplicationProperties properties;
	
	@Bean
	public RabbitAdmin rabbitAdmin(ConnectionFactory connectionFactory) {
		RabbitAdmin rabbitAdmin = new RabbitAdmin(connectionFactory);
		// 只有设置为 true，spring 才会加载 RabbitAdmin 这个类
		rabbitAdmin.setAutoStartup(true);
		return rabbitAdmin;
	}
	
	@Bean
	public RabbitTemplate rabbitTemplate(ConnectionFactory connectionFactory) {
		RabbitTemplate rabbitTemplate = new RabbitTemplate(connectionFactory);
		rabbitTemplate.setMessageConverter(new Jackson2JsonMessageConverter());
		return rabbitTemplate;
	}
	
	@Bean
	public SimpleRabbitListenerContainerFactory rabbitListenerContainerFactory(ConnectionFactory connectionFactory) {
		SimpleRabbitListenerContainerFactory factory = new SimpleRabbitListenerContainerFactory();
		factory.setConnectionFactory(connectionFactory);
		factory.setMessageConverter(new Jackson2JsonMessageConverter());
		return factory;
	}
	
    @Bean
    public TopicExchange commonTopicExchange() {
    	// 这里设置为true, 实际由回调机制保证消息的可靠性
        return new TopicExchange(properties.getCommonExchange(), true, false);
    }
    
	@Bean
	public void createExchange (){
		rabbitAdmin.declareExchange(commonTopicExchange());
	}
	
}

@Configurable
class RabbitInitializingBean implements InitializingBean {

	@Autowired
	private RabbitTemplate rabbitTemplate;
	
	@Override
	public void afterPropertiesSet() throws Exception {
		this.rabbitTemplate.setConfirmCallback(new CommonConfirmCallback());
	}
	
}
