package com.persagy.account.mapper;

import java.util.List;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.persagy.account.pojo.dto.SaasFunction;

/**
 * 功能信息
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021-03-13 15:29:50
 */
@Mapper
public interface SaasFunctionMapper extends BaseMapper<SaasFunction> {

	/**
	 * 查询出该账号下某菜单的功能点信息集合，关联查询
	 * 
	 * @param accountId
	 * @param groupCode
	 * @param roleId
	 * @param menuId
	 * @return
	 */
	List<SaasFunction> queryAccountFunctionList(@Param("accountId") String accountId, @Param("groupCode") String groupCode, @Param("menuId") String menuId);
	
	/**
	 * 查询出该角色下某菜单的功能点信息集合，关联查询
	 * 
	 * @param groupCode
	 * @param roleId
	 * @param menuId
	 * @param pageId
	 * @return
	 */
	List<SaasFunction> queryRoleFunctionList(@Param("groupCode") String groupCode, @Param("roleId") String roleId, 
			@Param("menuId") String menuId, @Param("pageId") String pageId);
	
	/**
	 * 获取此产品页面再此账号下所拥有的的页面权限
	 * @param accountId
	 * @param menuId
	 * @param pageId
	 * @return
	 */
	List<SaasFunction> queryProductPageFunctions(@Param("accountId") String accountId, @Param("menuId") String menuId, @Param("pageId") String pageId);
	
}
