package com.persagy.account.pojo.dto;

import java.util.Date;
import java.util.List;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.FieldStrategy;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.persagy.common.annotation.IdGeneratorPrefix;
import com.persagy.common.constant.SaasCommonConstant;
import com.persagy.common.model.BaseEntity;
import com.persagy.common.utils.StringUtil;

import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

/**
 * 区域信息
 * 
 * @version 1.0.0
 * @company persagy
 * @author zhangqiankun
 * @date 2021-03-13 15:29:50
 */
@Getter
@Setter
@ToString
@EqualsAndHashCode(callSuper = false)
@TableName("saas_area")
@IdGeneratorPrefix(SaasCommonConstant.SAAS_AREA_ID_PREFIX)
public class SaasArea extends BaseEntity<SaasArea> {
	private static final long serialVersionUID = -6778648944439996610L;

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String groupCode; // 集团编码
	
	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String parentId; // 上级区域ID

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String areaCode; // 区域编码

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String areaName; // 区域名称

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String areaType; // 区域类别，0-非最底层区域，1-最底层区域

	@TableField(fill = FieldFill.INSERT, updateStrategy = FieldStrategy.NOT_EMPTY)
	private Date createTime; // 创建时间

	@TableField(fill = FieldFill.INSERT_UPDATE, updateStrategy = FieldStrategy.NOT_EMPTY)
	private Date updateTime; // 更新时间

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String updateUser; // 最后一次操作者ID

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String remark; // 备注
	
	@TableField(exist = false)
	private List<SaasArea> childrens;	//下级区域
	
	@TableField(exist = false)
	private List<SaasProject> projects;		//底层区域对应的项目集合
	
	@TableField(exist = false)
	private Integer projectNum;		//当前区域及其所有下级区域包含的所有项目数

	public static class Builder {

		private LambdaQueryWrapper<SaasArea> queryWrapper = null;

		private LambdaUpdateWrapper<SaasArea> updateWrapper = null;

		public Builder createQueryWrapper() {
			queryWrapper = new LambdaQueryWrapper<SaasArea>();
			return this;
		}

		public Builder createUpdateWrapper() {
			updateWrapper = new LambdaUpdateWrapper<SaasArea>();
			return this;
		}

		public Builder idEq(String id) {
			if (StringUtil.isNotBlank(id)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasArea::getId, id);
				} else {
					queryWrapper.eq(SaasArea::getId, id);
				}
			}
			return this;
		}

		public Builder groupCodeEq(String groupCode) {
			if (StringUtil.isNotBlank(groupCode)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasArea::getGroupCode, groupCode);
				} else {
					queryWrapper.eq(SaasArea::getGroupCode, groupCode);
				}
			}
			return this;
		}
		
		public Builder parentIdEq(String parentId) {
			if (StringUtil.isNotBlank(parentId)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasArea::getParentId, parentId);
				} else {
					queryWrapper.eq(SaasArea::getParentId, parentId);
				}
			}
			return this;
		}
		
		public Builder parentIdIsNull() {
			if (updateWrapper != null) {
				updateWrapper.and(wrapper -> wrapper
						.isNull(SaasArea::getParentId)
						.or()
						.eq(SaasArea::getParentId, ""));
			} else {
				queryWrapper.and(wrapper -> wrapper
						.isNull(SaasArea::getParentId)
						.or()
						.eq(SaasArea::getParentId, ""));
			}
			return this;
		}

		public Builder areaCodeEq(String areaCode) {
			if (StringUtil.isNotBlank(areaCode)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasArea::getAreaCode, areaCode);
				} else {
					queryWrapper.eq(SaasArea::getAreaCode, areaCode);
				}
			}
			return this;
		}

		public Builder areaNameEq(String areaName) {
			if (StringUtil.isNotBlank(areaName)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasArea::getAreaName, areaName);
				} else {
					queryWrapper.eq(SaasArea::getAreaName, areaName);
				}
			}
			return this;
		}
		
		public Builder areaNameLike(String areaName) {
			if (StringUtil.isNotBlank(areaName)) {
				if (updateWrapper != null) {
					updateWrapper.like(SaasArea::getAreaName, areaName);
				} else {
					queryWrapper.like(SaasArea::getAreaName, areaName);
				}
			}
			return this;
		}

		public Builder areaTypeEq(String areaType) {
			if (StringUtil.isNotBlank(areaType)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasArea::getAreaType, areaType);
				} else {
					queryWrapper.eq(SaasArea::getAreaType, areaType);
				}
			}
			return this;
		}

		public Builder createTimeEq(Date createTime) {
			if (null != createTime) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasArea::getCreateTime, createTime);
				} else {
					queryWrapper.eq(SaasArea::getCreateTime, createTime);
				}
			}
			return this;
		}

		public Builder updateTimeEq(Date updateTime) {
			if (null != updateTime) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasArea::getUpdateTime, updateTime);
				} else {
					queryWrapper.eq(SaasArea::getUpdateTime, updateTime);
				}
			}
			return this;
		}

		public Builder updateUserEq(String updateUser) {
			if (StringUtil.isNotBlank(updateUser)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasArea::getUpdateUser, updateUser);
				} else {
					queryWrapper.eq(SaasArea::getUpdateUser, updateUser);
				}
			}
			return this;
		}

		public Builder remarkEq(String remark) {
			if (StringUtil.isNotBlank(remark)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasArea::getRemark, remark);
				} else {
					queryWrapper.eq(SaasArea::getRemark, remark);
				}
			}
			return this;
		}

		public LambdaQueryWrapper<SaasArea> builderQueryWrapper() {
			return queryWrapper;
		}

		public LambdaUpdateWrapper<SaasArea> builderUpdateWrapper() {
			return updateWrapper;
		}
	}
}
