package com.persagy.account.pojo.dto;

import java.util.Date;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.FieldStrategy;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.persagy.common.annotation.IdGeneratorPrefix;
import com.persagy.common.constant.SaasCommonConstant;
import com.persagy.common.model.BaseEntity;
import com.persagy.common.utils.StringUtil;

import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

/**
 * 集团签约产品
 * 
 * @version 1.0.0
 * @company persagy
 * @author zhangqiankun
 * @date 2021-05-07 12:02:40
 */
@Getter
@Setter
@ToString
@EqualsAndHashCode(callSuper = false)
@TableName("saas_group_product")
@IdGeneratorPrefix(SaasCommonConstant.SAAS_GROUP_PRODUCT_ID_PREFIX)
public class SaasGroupProduct extends BaseEntity<SaasGroupProduct> {
	private static final long serialVersionUID = -5143514069190729082L;

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String groupCode; // 集团编码

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String productId; // 产品ID

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String productCode; // 产品编码

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String productRange; // 产品使用范围，0-全部项目，1-部分项目

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private Date productContract; // 签约时间

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private Date validStartTime; // 签约有效期的开始时间

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private Date validEndTime; // 签约有效期的结束时间

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String validLast; // 签约有效期，0-期内有效，1-永久有效

	@TableField(fill = FieldFill.INSERT_UPDATE, updateStrategy = FieldStrategy.NOT_EMPTY)
	private Date updateTime; // 更新时间

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String updateUser; // 最后一次操作者ID
	
	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String remark; // 备注
	
	@TableField(exist = false)
	private Integer projectNum; // 该产品下签约的项目数量

	public static class BuilderQueryWrapper {

		private LambdaQueryWrapper<SaasGroupProduct> queryWrapper = new LambdaQueryWrapper<SaasGroupProduct>();

		public BuilderQueryWrapper idEq(String id) {
			if (StringUtil.isNotBlank(id)) {
				queryWrapper.eq(SaasGroupProduct::getId, id);
			}
			return this;
		}

		public BuilderQueryWrapper groupCodeEq(String groupCode) {
			if (StringUtil.isNotBlank(groupCode)) {
				queryWrapper.eq(SaasGroupProduct::getGroupCode, groupCode);
			}
			return this;
		}

		public BuilderQueryWrapper productIdEq(String productId) {
			if (StringUtil.isNotBlank(productId)) {
				queryWrapper.eq(SaasGroupProduct::getProductId, productId);
			}
			return this;
		}

		public BuilderQueryWrapper productCodeEq(String productCode) {
			if (StringUtil.isNotBlank(productCode)) {
				queryWrapper.eq(SaasGroupProduct::getProductCode, productCode);
			}
			return this;
		}

		public BuilderQueryWrapper productRangeEq(String productRange) {
			if (StringUtil.isNotBlank(productRange)) {
				queryWrapper.eq(SaasGroupProduct::getProductRange, productRange);
			}
			return this;
		}

		public BuilderQueryWrapper productContractEq(Date productContract) {
			if (null != productContract) {
				queryWrapper.eq(SaasGroupProduct::getProductContract, productContract);
			}
			return this;
		}

		public BuilderQueryWrapper validStartTimeEq(Date validStartTime) {
			if (null != validStartTime) {
				queryWrapper.eq(SaasGroupProduct::getValidStartTime, validStartTime);
			}
			return this;
		}

		public BuilderQueryWrapper validEndTimeEq(Date validEndTime) {
			if (null != validEndTime) {
				queryWrapper.eq(SaasGroupProduct::getValidEndTime, validEndTime);
			}
			return this;
		}

		public BuilderQueryWrapper validLastEq(String validLast) {
			if (StringUtil.isNotBlank(validLast)) {
				queryWrapper.eq(SaasGroupProduct::getValidLast, validLast);
			}
			return this;
		}

		public BuilderQueryWrapper remarkEq(String remark) {
			if (StringUtil.isNotBlank(remark)) {
				queryWrapper.eq(SaasGroupProduct::getRemark, remark);
			}
			return this;
		}

		public LambdaQueryWrapper<SaasGroupProduct> builder() {
			return queryWrapper;
		}

	}

	public static class BuilderUpdateWrapper {

		private LambdaUpdateWrapper<SaasGroupProduct> updateWrapper = new LambdaUpdateWrapper<SaasGroupProduct>();

		public BuilderUpdateWrapper idEq(String id) {
			if (StringUtil.isNotBlank(id)) {
				updateWrapper.eq(SaasGroupProduct::getId, id);
			}
			return this;
		}

		public BuilderUpdateWrapper groupCodeEq(String groupCode) {
			if (StringUtil.isNotBlank(groupCode)) {
				updateWrapper.eq(SaasGroupProduct::getGroupCode, groupCode);
			}
			return this;
		}

		public BuilderUpdateWrapper productIdEq(String productId) {
			if (StringUtil.isNotBlank(productId)) {
				updateWrapper.eq(SaasGroupProduct::getProductId, productId);
			}
			return this;
		}

		public BuilderUpdateWrapper productCodeEq(String productCode) {
			if (StringUtil.isNotBlank(productCode)) {
				updateWrapper.eq(SaasGroupProduct::getProductCode, productCode);
			}
			return this;
		}

		public BuilderUpdateWrapper productRangeEq(String productRange) {
			if (StringUtil.isNotBlank(productRange)) {
				updateWrapper.eq(SaasGroupProduct::getProductRange, productRange);
			}
			return this;
		}

		public BuilderUpdateWrapper productContractEq(Date productContract) {
			if (null != productContract) {
				updateWrapper.eq(SaasGroupProduct::getProductContract, productContract);
			}
			return this;
		}

		public BuilderUpdateWrapper validStartTimeEq(Date validStartTime) {
			if (null != validStartTime) {
				updateWrapper.eq(SaasGroupProduct::getValidStartTime, validStartTime);
			}
			return this;
		}

		public BuilderUpdateWrapper validEndTimeEq(Date validEndTime) {
			if (null != validEndTime) {
				updateWrapper.eq(SaasGroupProduct::getValidEndTime, validEndTime);
			}
			return this;
		}

		public BuilderUpdateWrapper validLastEq(String validLast) {
			if (StringUtil.isNotBlank(validLast)) {
				updateWrapper.eq(SaasGroupProduct::getValidLast, validLast);
			}
			return this;
		}

		public BuilderUpdateWrapper remarkEq(String remark) {
			if (StringUtil.isNotBlank(remark)) {
				updateWrapper.eq(SaasGroupProduct::getRemark, remark);
			}
			return this;
		}

		public LambdaUpdateWrapper<SaasGroupProduct> builder() {
			return updateWrapper;
		}

	}
}
