package com.persagy.account.pojo.dto;

import java.util.Date;
import java.util.List;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.FieldStrategy;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.persagy.common.annotation.IdGeneratorPrefix;
import com.persagy.common.constant.SaasCommonConstant;
import com.persagy.common.model.BaseEntity;
import com.persagy.common.utils.StringUtil;

import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

/**
 * 菜单信息
 * 
 * @version 1.0.0
 * @company persagy
 * @author zhangqiankun
 * @date 2021-03-13 15:29:50
 */
@Getter
@Setter
@ToString
@EqualsAndHashCode(callSuper = false)
@TableName("saas_menu")
@IdGeneratorPrefix(SaasCommonConstant.SAAS_MENU_ID_PREFIX)
public class SaasMenu extends BaseEntity<SaasMenu> {
	private static final long serialVersionUID = -4911716291586261567L;

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String parentId; // 上级菜单ID

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String appId; // 应用ID， PC-电脑端，APP-手机端

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String productId; // 产品ID
	
	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String menuCode; // 菜单编码

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String menuName; // 菜单名称

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String menuUrl; // 菜单URL
	
	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String urlType;	//URL类型，0-相对路径，1-绝对路径

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String menuIcon; // 菜单图标

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private Integer menuSort; // 菜单顺序
	
	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String menuType;	// 菜单类型，0-系统菜单，1-业务菜单

	@TableField(fill = FieldFill.INSERT, updateStrategy = FieldStrategy.NOT_EMPTY)
	private Date createTime; // 创建时间

	@TableField(fill = FieldFill.INSERT_UPDATE, updateStrategy = FieldStrategy.NOT_EMPTY)
	private Date updateTime; // 更新时间

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String updateUser; // 最后一次操作者ID

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String remark; // 备注

	@TableField(exist = false)
	private String groupCode; // 集团编码
	
	@TableField(exist = false)
	private String accountId; // 账号ID
	
	@TableField(exist = false)
	private String roleId;	//角色ID
	
	@TableField(exist = false)
	private String menuId;	//菜单ID
	
	@TableField(exist = false)
	private List<SaasMenu> childrens;	 //下级菜单
	
	@TableField(exist = false)
	private List<SaasProductPage> productPages; //此菜单下若有产品，代表顶级页面
	
	@TableField(exist = false)
	private List<SaasFunction> functions; //对应功能点集合
	
	public static class Builder {

		private LambdaQueryWrapper<SaasMenu> queryWrapper = null;

		private LambdaUpdateWrapper<SaasMenu> updateWrapper = null;

		public Builder createQueryWrapper() {
			queryWrapper = new LambdaQueryWrapper<SaasMenu>();
			return this;
		}

		public Builder createUpdateWrapper() {
			updateWrapper = new LambdaUpdateWrapper<SaasMenu>();
			return this;
		}

		public Builder idEq(String id) {
			if (StringUtil.isNotBlank(id)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasMenu::getId, id);
				} else {
					queryWrapper.eq(SaasMenu::getId, id);
				}
			}
			return this;
		}

		public Builder parentIdEq(String parentId) {
			if (StringUtil.isNotBlank(parentId)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasMenu::getParentId, parentId);
				} else {
					queryWrapper.eq(SaasMenu::getParentId, parentId);
				}
			}
			return this;
		}

		public Builder appIdEq(String appId) {
			if (StringUtil.isNotBlank(appId)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasMenu::getAppId, appId);
				} else {
					queryWrapper.eq(SaasMenu::getAppId, appId);
				}
			}
			return this;
		}
		
		public Builder productId(String productId) {
			if (StringUtil.isNotBlank(productId)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasMenu::getProductId, productId);
				} else {
					queryWrapper.eq(SaasMenu::getProductId, productId);
				}
			}
			return this;
		}
		
		public Builder menuCodeEq(String menuCode) {
			if (StringUtil.isNotBlank(menuCode)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasMenu::getMenuCode, menuCode);
				} else {
					queryWrapper.eq(SaasMenu::getMenuCode, menuCode);
				}
			}
			return this;
		}

		public Builder menuNameEq(String menuName) {
			if (StringUtil.isNotBlank(menuName)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasMenu::getMenuName, menuName);
				} else {
					queryWrapper.eq(SaasMenu::getMenuName, menuName);
				}
			}
			return this;
		}

		public Builder menuUrlEq(String menuUrl) {
			if (StringUtil.isNotBlank(menuUrl)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasMenu::getMenuUrl, menuUrl);
				} else {
					queryWrapper.eq(SaasMenu::getMenuUrl, menuUrl);
				}
			}
			return this;
		}
		
		public Builder urlTypeEq(String urlType) {
			if (StringUtil.isNotBlank(urlType)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasMenu::getUrlType, urlType);
				} else {
					queryWrapper.eq(SaasMenu::getUrlType, urlType);
				}
			}
			return this;
		}

		public Builder menuIconEq(String menuIcon) {
			if (StringUtil.isNotBlank(menuIcon)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasMenu::getMenuIcon, menuIcon);
				} else {
					queryWrapper.eq(SaasMenu::getMenuIcon, menuIcon);
				}
			}
			return this;
		}

		public Builder menuSortEq(Integer menuSort) {
			if (null != menuSort) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasMenu::getMenuSort, menuSort);
				} else {
					queryWrapper.eq(SaasMenu::getMenuSort, menuSort);
				}
			}
			return this;
		}
		
		public Builder menuTypeEq(String menuType) {
			if (StringUtil.isNotBlank(menuType)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasMenu::getMenuType, menuType);
				} else {
					queryWrapper.eq(SaasMenu::getMenuType, menuType);
				}
			}
			return this;
		}
		
		public Builder createTimeEq(Date createTime) {
			if (null != createTime) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasMenu::getCreateTime, createTime);
				} else {
					queryWrapper.eq(SaasMenu::getCreateTime, createTime);
				}
			}
			return this;
		}

		public Builder updateTimeEq(Date updateTime) {
			if (null != updateTime) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasMenu::getUpdateTime, updateTime);
				} else {
					queryWrapper.eq(SaasMenu::getUpdateTime, updateTime);
				}
			}
			return this;
		}

		public Builder updateUserEq(String updateUser) {
			if (StringUtil.isNotBlank(updateUser)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasMenu::getUpdateUser, updateUser);
				} else {
					queryWrapper.eq(SaasMenu::getUpdateUser, updateUser);
				}
			}
			return this;
		}

		public Builder remarkEq(String remark) {
			if (StringUtil.isNotBlank(remark)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasMenu::getRemark, remark);
				} else {
					queryWrapper.eq(SaasMenu::getRemark, remark);
				}
			}
			return this;
		}

		public LambdaQueryWrapper<SaasMenu> builderQueryWrapper() {
			return queryWrapper;
		}

		public LambdaUpdateWrapper<SaasMenu> builderUpdateWrapper() {
			return updateWrapper;
		}
	}
}
