package com.persagy.account.pojo.vo.account;

import java.util.Date;
import java.util.List;
import java.util.Set;

import javax.validation.constraints.NotBlank;

import com.persagy.common.constant.SaasCommonConstant;
import com.persagy.account.pojo.vo.auth.SaasAccountRoleVO;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

/**
 * 项目信息
 * 
 * @version 1.0.0
 * @company persagy
 * @author zhangqiankun
 * @date 2021-03-13 15:29:50
 */
@Getter
@Setter
@ApiModel
@ToString
public class SaasAccountCreateVO {

	@ApiModelProperty(value = "主键ID，更新时不可为空", example = "123456adzxzc")
	private String accountId; 	// 当前账号ID
	
	@ApiModelProperty(value = "关联类型，0-主岗，1-副岗，2-业务超管默认角色", example = "0")
	private String casType; 	// 关联类型，0-主岗，1-副岗，2-业务超管默认角色，这里关联类型会直接插入数据库中，不做为重置的条件
	
	@ApiModelProperty(value = "主键ID，更新时不可为空", example = "123456adzxzc")
	private List<SaasAccountRoleVO> roles; 	// 账号关联的角色ID集合
	
	//@NotBlank(message = "集团编码，不可为空")
	@ApiModelProperty(value = "集团编码，作为SQL条件", required = true, example = "RC")
	private String groupCode; 	// 所属集团编码
	
	//@NotBlank(message = "应用ID，不可为空")
	@ApiModelProperty(value = "账号所属终端， PC-电脑端，APP-手机应用端", example = "PC", required = true)
    private Set<String> terminal;	//后续若账号区分端的话，可以放弃appId，改为 terminal
	
	@NotBlank(message = "应用ID，不可为空")
	@ApiModelProperty(value = "应用ID， PC-电脑端，APP-手机应用端", example = "PC", required = true)
    private String appId;
	
	@NotBlank(message = "登录用户名，不可为空")
	@ApiModelProperty(value = "登录用户名", example = "zhangsan", required = true)
	private String username; // 登录用户名
	
	//@NotBlank(message = "登录密码，不可为空")
	@ApiModelProperty(value = "登录密码", example = "zhangsan", required = true)
	private String password; // 登录密码

	@ApiModelProperty(value = "手机号", example = "18888888888")
	private String phoneNum; // 手机号
	
	@ApiModelProperty(value = "邮箱", example = "18888888888@163.com")
	private String mail; // 邮箱
	
	@ApiModelProperty(value = "头像，图片URL", example = "http://127.0.0.1:9980/test.img")
	private String headPortrait; // 头像，图片URL

	@NotBlank(message = "账号类型，不可为空")
	@ApiModelProperty(value = "账号类型, 0-超级管理员(所有集团)，1-单集团管理员(单集团)，2-普通账号", example = "0")
	private String accountType;		//账号类型, 0-超级管理员(所有集团)，1-单集团管理员(单集团)，2-普通账号
	
	@NotBlank(message = "账号所属，不可为空")
	@ApiModelProperty(value = "账号所属, 0-运维系统账号，1-业务账号", example = "0")
	private String accountBelong;	//账号所属, 0-运维系统账号，1-业务账号
	
	//@NotBlank(message = "账号来源，不可为空")
	@ApiModelProperty(value = "账号来源", example = "persagy", required = true)
	private String accountSource = SaasCommonConstant.ACCOUNT_SOURCE_PERSAGE; // 账号来源

	//@NotNull(message = "账号有效期的开始时间，不可为空")
	@ApiModelProperty(value = "账号有效期的开始时间[时间戳：1615720476050]", example = "1615720476050")	
	private Date validStartTime; // 账号有效期的开始时间
	
	//@NotNull(message = "账号有效期的结束时间，不可为空")
	@ApiModelProperty(value = "账号有效期的结束时间[时间戳：1615720476050]", example = "1615720476050")
	private Date validEndTime; 	// 账号有效期的结束时间

	@NotBlank(message = "账号有效期，不可为空")
	@ApiModelProperty(value = "账号有效期，0-期内有效，1-永久有效", example = "1",  required = true)
	private String validLast;	//账号有效期，0-期内有效，1-永久有效
	
	@ApiModelProperty(value = "备注", example = "测试账号")
	private String remark; 		// 备注
	
	//@NotBlank(message = "账号状态不可为空")
	@ApiModelProperty(value = "是否可用，0-不可用，1-可用", example = "1")
	private Integer valid; 		// 0-不可用，1-可用
	
	private boolean isVerify = true;		// 是否进行验证集团编码必填, true-验证，false-不验证

}
