package com.persagy.account.pojo.vo.product;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;

import com.persagy.common.constant.SaasCommonConstant;
import com.persagy.common.model.BaseUserModel;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

/**
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021年5月6日 上午10:21:23
 */
@Getter
@Setter
@ApiModel
@ToString
public class SaasProductPageCreateVO extends BaseUserModel {
	
	@ApiModelProperty(value = "页面ID，更新时不可为空", example = "PD1001")
	private String id; // 页面ID
	
	@NotBlank(message = "产品ID，不可为空")
	@ApiModelProperty(value = "产品ID", example = "PD1001", required = true)
	private String productId; // 产品ID

	@ApiModelProperty(value = "上级页面ID", example = "1001")
	private String parentId; // 上级页面ID

	@NotBlank(message = "页面名称，不可为空")
	@ApiModelProperty(value = "页面名称", example = "1001", required = true)
	private String pageName; // 页面名称
	
	@ApiModelProperty(value = "页面图标", example = "1001")
	private String pageIcon; // 页面图标

	@ApiModelProperty(value = "页面URL", example = "1001")
	private String pageUrl; // 页面URL，一般为前端页面跳转链接

	@NotBlank(message = "页面视角，不可为空")
	@ApiModelProperty(value = "页面视角，0-集团项目页，1-集团独有页，2-项目独有页", example = "1001", required = true)
	private String pageAngle; // 页面视角，0-集团项目页，1-集团独有页，2-项目独有页

	@ApiModelProperty(value = "是否为落地页，0-非落地页，1-集团落地页，2-项目落地页，3-集团项目落地页，默认0", example = "1001", required = true)
	private String pageFloor = SaasCommonConstant.STR_STATUS_0; // 是否为落地页，0-非落地页，1-集团落地页，2-项目落地页，3-集团项目落地页
	
	@NotNull(message = "页面顺序，不可为空")
	@ApiModelProperty(value = "页面顺序", example = "1", required = true)
	private Integer pageSort;	// 页面顺序
	
	@ApiModelProperty(value = "备注", example = "1001")
	private String remark; // 备注
	
}
