package com.persagy.account.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import com.persagy.common.constant.SaasCommonConstant;
import com.persagy.common.exception.BusinessException;
import com.persagy.common.service.impl.SuperServiceImpl;
import com.persagy.account.mapper.SaasAccountRoleMapper;
import com.persagy.account.mapper.SaasRoleMapper;
import com.persagy.account.pojo.dto.SaasAccountRole;
import com.persagy.account.pojo.dto.SaasRole;
import com.persagy.account.pojo.vo.auth.SaasAccountRoleVO;
import com.persagy.account.service.ISaasAccountRoleService;

import cn.hutool.core.collection.CollectionUtil;

/**
 * 账号-角色关联信息
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021-03-13 15:29:50
 */
@Service
public class SaasAccountRoleServiceImpl extends SuperServiceImpl<SaasAccountRoleMapper, SaasAccountRole> implements ISaasAccountRoleService {

	@Autowired
	private SaasRoleMapper saasRoleMapper;
	
	@Override
	public boolean isAllowDeleteRole(String groupCode, String roleId) {
		LambdaQueryWrapper<SaasRole> queryWrapper = new SaasRole.Builder().createQueryWrapper().groupCodeEq(groupCode)
				.idEq(roleId).roleTypeEq(SaasCommonConstant.STR_STATUS_2).builderQueryWrapper();
		List<SaasRole> selectList = this.saasRoleMapper.selectList(queryWrapper);
		if (CollectionUtil.isNotEmpty(selectList)) {
			return false;		//业务超管角色不允许被删除
		}
		Integer result = this.baseMapper.isAllowDeleteRole(groupCode, roleId, SaasCommonConstant.STATUS_1);
		if (result == null || result < 1) {
			return true;
		}
		return false;
	}

	@Override	
	@Transactional
	public boolean resetSaasAccountRole(String groupCode, String accountId, String casType, List<SaasAccountRoleVO> roles) {
		// 1.先删除此账号的所有角色，再添加
		LambdaQueryWrapper<SaasAccountRole> queryWrapper = new SaasAccountRole.Builder().createQueryWrapper()
				.accountIdEq(accountId).groupCodeEq(groupCode).casTypeEq(casType).builderQueryWrapper();
		this.baseMapper.delete(queryWrapper);
		Integer result = this.baseMapper.batchInsertSaasAccountRole(groupCode, accountId, roles);
		return SqlHelper.retBool(result);
	}

	@Override
	@Transactional
	public boolean addDeafultAccountRole(String accountId, String groupCode) {
		// 获取默认的角色--业务超管角色
		LambdaQueryWrapper<SaasRole> queryWrapper = new SaasRole.Builder().createQueryWrapper().groupCodeEq(groupCode)
				.roleTypeEq(SaasCommonConstant.STR_STATUS_2).validEq(SaasCommonConstant.STATUS_1).builderQueryWrapper();
		SaasRole saasRole = this.saasRoleMapper.selectOne(queryWrapper);
		if (saasRole == null) {
			throw new BusinessException("业务超管账号的默认角色信息不存在");
		}
		SaasAccountRole saasAccountRole = new SaasAccountRole();
		saasAccountRole.setAccountId(accountId);
		saasAccountRole.setGroupCode(groupCode);
		saasAccountRole.setCasType(SaasCommonConstant.STR_STATUS_2);
		saasAccountRole.setRoleId(saasRole.getId());
		int result = this.baseMapper.insert(saasAccountRole);
		return SqlHelper.retBool(result);
	}

}
