package com.persagy.account.service.impl;

import java.util.List;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import com.persagy.common.constant.SaasCommonConstant;
import com.persagy.common.service.impl.SuperServiceImpl;
import com.persagy.common.utils.StringUtil;
import com.persagy.account.mapper.SaasAreaMapper;
import com.persagy.account.pojo.dto.SaasArea;
import com.persagy.account.service.ISaasAreaService;

/**
 * 区域信息
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021-03-13 15:29:50
 */
@Service
public class SaasAreaServiceImpl extends SuperServiceImpl<SaasAreaMapper, SaasArea> implements ISaasAreaService {

	@Override
	public SaasArea getAreaOne(String id, String groupCode, String areaCode, String areaName) {
		LambdaQueryWrapper<SaasArea> queryWrapper = new SaasArea.Builder().createQueryWrapper().idEq(id)
    			.groupCodeEq(groupCode).areaCodeEq(areaCode).areaNameLike(areaName).builderQueryWrapper();
    	return this.baseMapper.selectOne(queryWrapper);
	}
	
	@Override
	public List<SaasArea> queryAllowSaasAreaList(String accountId, SaasArea saasArea) {
		return this.baseMapper.queryAllowSaasAreaList(accountId, saasArea);
	}
	
	@Override
	public boolean validAreaCodeAndName(String groupCode, String areaCode, String areaName, String id) {
		LambdaQueryWrapper<SaasArea> queryWrapper = null;
		// 1.验证区域编码
		if (StringUtil.isNotBlank(areaCode)) {
			queryWrapper = new SaasArea.Builder().createQueryWrapper().groupCodeEq(groupCode).areaCodeEq(areaCode).idEq(id).builderQueryWrapper();
			SaasArea selectOne = this.baseMapper.selectOne(queryWrapper);
			if (selectOne != null && StringUtil.isBlank(id)) {
				return false;
			}
			if (StringUtil.isNotBlank(id) && selectOne != null && !id.equals(selectOne.getId())) {
				return false;
			}
		}
		// 2.验证区域名称
		if (StringUtil.isNotBlank(areaName)) {
			queryWrapper = new SaasArea.Builder().createQueryWrapper().groupCodeEq(groupCode).areaNameEq(areaName).idEq(id).builderQueryWrapper();
			SaasArea selectOne = this.baseMapper.selectOne(queryWrapper);
			if (selectOne != null && StringUtil.isBlank(id)) {
				return false;
			}
			if (StringUtil.isNotBlank(id) && selectOne != null && !id.equals(selectOne.getId())) {
				return false;
			}
		}
		return true;
	}

	@Override
	@Transactional
	public String createEmptyAreaInfo(String groupCode, String updateUser) {
		SaasArea saasArea = new SaasArea();
		saasArea.setGroupCode(groupCode);
		saasArea.setAreaName("未分区");
		saasArea.setAreaCode(SaasCommonConstant.STR_STATUS_MINUS_1);
		saasArea.setAreaType(SaasCommonConstant.STR_STATUS_1);
		saasArea.setRemark("项目未有分区");
		saasArea.setUpdateUser(updateUser);
		int insert = this.baseMapper.insert(saasArea);
		if (SqlHelper.retBool(insert)) {
			return saasArea.getId();
		}
		return null;
	}

}
