package com.persagy.account.service.impl;

import java.util.List;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import com.google.common.collect.Lists;
import com.persagy.common.constant.SaasCommonConstant;
import com.persagy.common.service.impl.SuperServiceImpl;
import com.persagy.common.utils.StringUtil;
import com.persagy.account.mapper.SaasProjectMapper;
import com.persagy.account.pojo.dto.SaasProject;
import com.persagy.account.service.ISaasProjectService;

import cn.hutool.core.collection.CollectionUtil;

/**
 * 项目信息
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021-03-13 15:29:50
 */
@Service
public class SaasProjectServiceImpl extends SuperServiceImpl<SaasProjectMapper, SaasProject> implements ISaasProjectService {

	@Override
	public SaasProject getOne(String groupCode, String projectId) {
		LambdaQueryWrapper<SaasProject> queryWrapper = new SaasProject.Builder().createQueryWrapper().groupCodeEq(groupCode)
				.projectIdEq(projectId).validEq(SaasCommonConstant.STATUS_1).builderQueryWrapper();
		return this.baseMapper.selectOne(queryWrapper);
	}
	
	@Override
	public Page<SaasProject> querySaasProjectList(SaasProject saasProject, Integer page, Integer size) {
		if (CollectionUtil.isEmpty(saasProject.getProjectIds())) {
			saasProject.setProjectIds(null);
		}
		Integer startRow = null;
		Page<SaasProject> pageRecord = new Page<SaasProject>();
		if (page != null && size != null) {
	    	startRow = (page - 1) * size;
	    	pageRecord.setCurrent(page);
			pageRecord.setSize(size);
		}
		List<SaasProject> list = this.baseMapper.querySaasProjectList(saasProject, startRow, size);
		if (CollectionUtil.isEmpty(list)) {
			pageRecord.setRecords(Lists.newArrayList());
			pageRecord.setTotal(0);
			return pageRecord;
		}
		if (startRow != null) {
			// 查询出总记录数大小
			LambdaQueryWrapper<SaasProject> queryWrapper = new SaasProject.Builder().createQueryWrapper()
					.idEq(saasProject.getId()).groupCodeEq(saasProject.getGroupCode()).projectIdEq(saasProject.getProjectId())
					.projectIdIn(saasProject.getProjectIds()).areaIdEq(saasProject.getAreaId()).projectLocalIdEq(saasProject.getProjectLocalId())
					.projectNameLike(saasProject.getProjectName()).provinceCodeEq(saasProject.getProvinceCode())
					.cityCodeEq(saasProject.getCityCode()).zoneCodeEq(saasProject.getZoneCode())
					.updateUserEq(saasProject.getUpdateUser()).validEq(saasProject.getValid()).builderQueryWrapper();
			queryWrapper.select(SaasProject::getId);
			int count = this.baseMapper.selectCount(queryWrapper);
			pageRecord.setTotal(count);
		} else {
			pageRecord.setTotal(list.size());
		}
		pageRecord.setRecords(list);
		return pageRecord;
	}
	
	@Override
	public Page<SaasProject> queryMoreProjectInfo(SaasProject saasProject, Integer page, Integer size) {
		if (CollectionUtil.isEmpty(saasProject.getProjectIds())) {
			saasProject.setProjectIds(null);
		}
		Integer startRow = null;
		Page<SaasProject> pageRecord = new Page<SaasProject>();
		if (page != null && size != null) {
	    	startRow = (page - 1) * size;
	    	pageRecord.setCurrent(page);
			pageRecord.setSize(size);
		}
		List<SaasProject> list = this.baseMapper.queryMoreProjectInfo(saasProject, startRow, size);
		if (CollectionUtil.isEmpty(list)) {
			pageRecord.setRecords(Lists.newArrayList());
			pageRecord.setTotal(0);
			return pageRecord;
		}
		if (startRow != null) {
			Integer count = this.baseMapper.queryCountMoreProject(saasProject);
			pageRecord.setTotal(count == null ? 0 : count);
		} else {
			pageRecord.setTotal(list.size());
		}
		pageRecord.setRecords(list);
		return pageRecord;
	}
	
	@Override
	public List<SaasProject> queryAllowGroupProjectList(String groupCode, String accountId) {
		return this.baseMapper.queryAllowGroupProjectList(groupCode, accountId, SaasCommonConstant.STATUS_1);
	}
	
	@Override
	public boolean validProjectData(SaasProject saasProject, boolean isUpdate) {
		LambdaQueryWrapper<SaasProject> queryWrapper = null;
		// 1.验证项目ID
		if (StringUtil.isNotBlank(saasProject.getProjectId())) {
			queryWrapper = new SaasProject.Builder().createQueryWrapper().groupCodeEq(saasProject.getGroupCode())
					.projectIdEq(saasProject.getProjectId()).validEq(SaasCommonConstant.STATUS_1).builderQueryWrapper();
			SaasProject selectOne = this.baseMapper.selectOne(queryWrapper);
			if (selectOne != null && !(isUpdate && selectOne.getId().equals(saasProject.getId()))) {
				return false;
			}
		}
		// 2.验证项目本地编码
		if (StringUtil.isNotBlank(saasProject.getProjectLocalId())) {
			queryWrapper = new SaasProject.Builder().createQueryWrapper().groupCodeEq(saasProject.getGroupCode())
					.projectLocalIdEq(saasProject.getProjectLocalId()).validEq(SaasCommonConstant.STATUS_1).builderQueryWrapper();
			SaasProject selectOne = this.baseMapper.selectOne(queryWrapper);
			if (selectOne != null && !(isUpdate && selectOne.getId().equals(saasProject.getId()))) {
				return false;
			}
		}
		// 3.验证项目名称
		if (StringUtil.isNotBlank(saasProject.getProjectName())) {
			queryWrapper = new SaasProject.Builder().createQueryWrapper().groupCodeEq(saasProject.getGroupCode())
					.projectNameEq(saasProject.getProjectName()).validEq(SaasCommonConstant.STATUS_1).builderQueryWrapper();
			SaasProject selectOne = this.baseMapper.selectOne(queryWrapper);
			if (selectOne != null && !(isUpdate && selectOne.getId().equals(saasProject.getId()))) {
				return false;
			}
		}
		return true;
	}

	@Override
	@Transactional
	public boolean batchInsertProjectData(List<SaasProject> list) {
		Integer result = this.baseMapper.batchInsertProjectData(list);
		return SqlHelper.retBool(result);
	}

	@Override
	@Transactional
	public boolean batchUpdateProjectArea(SaasProject saasProject, List<String> projectIds) {
		Integer result = this.baseMapper.batchUpdateProjectArea(saasProject, projectIds);
		return SqlHelper.retBool(result);
	}

	@Override
	public int countAllowProjectNum(String groupCode, String accountId, String areaId) {
		Integer result = this.baseMapper.countAllowProjectNum(groupCode, accountId, areaId, SaasCommonConstant.STATUS_1);
		return result == null ? 0 : result;
	}

}
