package com.persagy.sso.service.impl;

import com.persagy.common.utils.ResponseResult;
import com.persagy.sso.client.SaasAccountClient;
import com.persagy.sso.pojo.dto.AccountDTO;
import com.persagy.sso.pojo.dto.QueryRoleDTO;
import com.persagy.sso.pojo.dto.SaasAccountCreateDTO;
import com.persagy.sso.service.IAccountService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * @ClassName : AccountService
 * @Author ：xgq
 * @Date ：Created in 2021/4/16 0:40
 * @Description： TODO
 * @Version : 1.0
 */
@Slf4j
@Service
public class AccountService implements IAccountService {

    @Autowired
    private SaasAccountClient saasAccountClient;
    /**
     * @Description: 根据条件查询账号信息
     * @Author: xgq
     * @Date: 2021/4/16 0:44
     * @param accountDTO:
     * @return: com.persagy.common.utils.ResponseResult
     **/
    @Override
    public ResponseResult queryAccountByCondition(AccountDTO accountDTO) {
        return saasAccountClient.queryAccountByCondition(accountDTO);
    }

    /**
     * @Description: 根据账号查询角色
     * @Author: xgq
     * @Date: 2021/4/16 1:45
     * @param queryRoleDTO :
     * @param token
     * @return: com.persagy.common.utils.ResponseResult
     **/
    @Override
    public ResponseResult queryRoleByAccount(QueryRoleDTO queryRoleDTO, String token) {
        return saasAccountClient.queryRoleByAccount(queryRoleDTO,token);
    }


    /**
     * @Description: 更新账号
     * @Author: xgq
     * @Date: 2021/4/16 2:27
     * @param createDTO :
     * @param token
     * @return: com.persagy.common.utils.ResponseResult
     **/
    @Override
    public ResponseResult updateAccount(SaasAccountCreateDTO createDTO, String token) {
        return saasAccountClient.updateAccount(createDTO,token);
    }

    /**
     * @Description: 新增账号信息
     * @Author: xgq
     * @Date: 2021/4/16 9:54
     * @param createDTO :
     * @param token
     * @return: com.persagy.common.utils.ResponseResult
     **/
    @Override
    public ResponseResult insertAccount(SaasAccountCreateDTO createDTO, String token) {
        return saasAccountClient.insertAccount(createDTO,token);
    }

    /**
     * @Description: 根据账号来源查询账号
     * @Author: xgq
     * @Date: 2021/4/29 10:27
     * @param accountDTO:
     * @param token:
     * @return: com.persagy.common.utils.ResponseResult
     **/
    @Override
    public ResponseResult queryAccountListBySource(AccountDTO accountDTO, String token) {
        return saasAccountClient.queryAccountListBySource(accountDTO,token);
    }

    /**
     * @Description: 根据id批量删除
     * @Author: xgq
     * @Date: 2021/4/29 18:32
     * @param accountDTO :
     * @param token :
     * @return: com.persagy.common.utils.ResponseResult
     **/
    @Override
    public ResponseResult deleteByIds(AccountDTO accountDTO, String token) {
        return saasAccountClient.deleteByIds(accountDTO,token);
    }

    @Override
    public ResponseResult queryAccountById(AccountDTO accountDTO, String token) {
        return saasAccountClient.queryAccountListBySource(accountDTO,token);
    }
}
