package com.persagy.sso.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.persagy.common.exception.BusinessException;
import com.persagy.common.utils.ResponseResult;
import com.persagy.common.utils.ResponseResultUtil;
import com.persagy.security.util.SecureAES;
import com.persagy.sso.constant.BaseConstant;
import com.persagy.sso.manage.SynUserManage;
import com.persagy.sso.pojo.dto.*;
import com.persagy.sso.service.*;
import com.persagy.sso.util.BaseUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.naming.ldap.HasControls;
import java.util.*;

/**
 * @ClassName : SynUserService
 * @Author ：xgq
 * @Date ：Created in 2021/4/13 22:07
 * @Description： TODO
 * @Version : 1.0
 */
@Service
@Slf4j
public class SynUserService implements ISynUserService {
    @Autowired
    private IUserService userService;
    @Autowired
    private SynUserManage synUserManage;
    @Autowired
    private IDeptReflexService deptReflexService;
    @Autowired
    private IJobReflexService jobReflexService;
    @Autowired
    private IAccountReflexService accountReflexService;
    @Value("${saas.secure.aes.key}")
    private String aesKey;

    @Value("${saas.secure.aes.iv}")
    private String aesIv;

    
    /**
     * @Description: 同步人员信息------走定时任务
     * @Author: xgq
     * @Date: 2021/4/14 23:19

     * @return: com.persagy.common.utils.ResponseResult
     **/
    public ResponseResult synUserList() throws Exception{
        return synUserInfo();
    }


    /**
     * @Description: 全量同步人员信息
     * @Author: xgq
     * @Date: 2021/4/13 22:09
     * @return: com.persagy.common.utils.ResponseResult
     **/
    @Override
    public ResponseResult synUserInfo() throws Exception{
        //生成token，调用其他服务使用
        JSONObject token = new JSONObject();
        token.put(BaseConstant.ACCOUNT_ID,BaseConstant.SYSTEM_ID);
        token.put(BaseConstant.GROUP_CODE, BaseConstant.GROUP_CODE_WD);
        token.put(BaseConstant.APP_ID, BaseConstant.APP_ID_PC);
        //账号所属, 0-运维系统账号，1-业务账号，必填
        token.put(BaseConstant.ACCOUNT_BELONG, BaseConstant.RESOURCE_FROM_OA_WD);
        //加密
        SecureAES aes = new  SecureAES(aesKey,aesIv);
        String tokenStr = aes.encryptAccount(token);
        //实际参数： 加密后的param+.+token
        tokenStr = tokenStr + BaseConstant.SEPARATE_CODE + BaseConstant.DEFAULT_TOKEN;
        //查询数据库，获取对应的用户信息
        //测试用数据库： 39.102.43.1799934  wd_org   wd  NjnTECQh3:s9
        List<WdUser> userList = synUserManage.querySynUserList();
        if(CollectionUtils.isEmpty(userList)){
            log.info("no user info ...");
            return ResponseResultUtil.successResult();
        }
        //开始同步数据逻辑---同步简化版的oa结构
       // synDeptJobPersonInfo(tokenStr,userList);
        //开始同步数据逻辑---以同步人员数据为主
        synAccountInfo(tokenStr,userList);
        return ResponseResultUtil.successResult("全量同步用户信息成功...");
}


    /**
     * @Description: 同步逻辑
     * @Author: xgq
     * @Date: 2021/4/27 20:53
     * @param token:
     * @param userList:
     * @return: void
     **/
    private void synAccountInfo(String token, List<WdUser> userList) {
        //查询所有的映射信息
        List<WdAccount> accountReflexList = synUserManage.queryAllReflexList();
        //转成一个map，key:employeeId value:WdAccount
        Map<String, WdAccount> reflexAccountMap = new HashMap<>();
         if(CollectionUtils.isNotEmpty(accountReflexList)){
             //之前已经同步过数据，获取映射关系
             getReflexMap(accountReflexList,reflexAccountMap);
         }
         //处理之前的错误数据：应该删除未删除
        try {
            synUserManage.dealDeletedSynAccount(reflexAccountMap,token);
        } catch (Exception e) {
            log.error("deal deleted account error,reason: "+e.getMessage());
        }
        //待同步的数据
        for (int i = 0; i <userList.size() ; i++) {
            WdUser user = userList.get(i);
            try {
                synAccountItem(user,reflexAccountMap,token);
            } catch (Exception e) {
                log.error("syn user(id:"+(user.getEmployeeID()) +") error, reason: "+e.getMessage());
            }
        }
        //判断map的值，如果没有需要删除的账号，那么map应该是空的
        if(reflexAccountMap.isEmpty()){
            log.info("no delete employee....");
        } else {
            //留下的都是被删除的
            try {
                synUserManage.deleteSynAccount(reflexAccountMap,token);
                log.info("delete employee success...");
            } catch (Exception e) {
                log.error("delete employee error, reason: "+e.getMessage());
            }
        }
        log.info("syn account info end ...");
    }



    private void getReflexMap(List<WdAccount> accountReflexList, Map<String, WdAccount> reflexAccountMap) {
        for (int i = 0; i <accountReflexList.size() ; i++) {
            WdAccount wdAccount = accountReflexList.get(i);
            String employeeId = wdAccount.getEmployeeId();
            reflexAccountMap.put(employeeId, wdAccount);
        }
    }


    private void synAccountItem(WdUser user, Map<String, WdAccount> reflexAccountMap, String token) {
        //参数校验
        String username = user.getUsername();
        String employeeId = user.getEmployeeID();
        if(StringUtils.isBlank(username)|| StringUtils.isBlank(employeeId)){
            //数据不完整，不同步该数据，直接返回
            return ;
        }
        //查询账号id在映射表是否存在(判断是新增还是修改)
        if(!reflexAccountMap.containsKey(employeeId)){
            //之前不存在，新增
            //查询账号名称在账号表是否存在
            JSONObject account = synUserManage.queryAccountByCondition(username,token);
          //正常应该不存在
         if(null==account){
             //保存账号数据
             synUserManage.saveAccountItem(user,token);
         } else { //账号名称已经存在
             throw new BusinessException("username: " +username + "is exit...");
         }
        } else {
        //之前已经存在，修改信息,
            // 账号表没有需要修改的信息，只修改映射表
            //查询下是否存在，如果不存在，说明是之前同步的时候有问题，新建就行，正常应该存在
                WdAccount wdAccount = reflexAccountMap.get(employeeId);
            String accountId = wdAccount.getAccountId();
            if(StringUtils.isBlank(accountId)){
                //删除映射，重新添加
                synUserManage.deleteAccountReflexById(wdAccount.getId());
                synUserManage.saveAccountItem(user,token);
            } else {
                //根据账号去查这条数据，没有就新建
                JSONObject accountJson = synUserManage.queryAccountById(accountId,token);
                if(null == accountJson ){
                    synUserManage.deleteAccountReflexById(wdAccount.getId());
                    synUserManage.saveAccountItem(user,token);
                } else {
                    synUserManage.updateAccountItem(wdAccount,user, token);
                }
            }
             //删除修改的数据
            reflexAccountMap.remove(employeeId);
            }
        }



    /**
     * @Description: 同步逻辑
     * @Author: xgq
     * @Date: 2021/4/15 1:07
     * @param token :
     * @param userList :
     * @return: void
     **/
    private void synDeptJobPersonInfo(String token, List<WdUser> userList) {
        //定义
        WdUser user;
        AddDepartmentDTO addDepartmentDTO =new AddDepartmentDTO() ;
        AddJobDTO addJobDTO = new AddJobDTO();
        DeptReflex deptReflex = new DeptReflex();
        JobReflex jobReflex = new JobReflex();
        String oaDeptId = "";
        String oaDeptName = "";
        String oaJobId = "" ;
        String oaJobName = "" ;
        String deptId = "";
        String jobId = "" ;
        String accountId = "" ;
        //获取集团级部门，没有就创建一个
        String deptParentId =  getGroupDeptId(addDepartmentDTO,token);
        //遍历数据库，获取所有的部门信息,岗位信息，人员信息
        for (int i = 0; i <userList.size() ; i++) {
            user = userList.get(i);
            // 同步部门数据
            try {
                 deptId = dealDeptInfo(user,oaDeptId,oaDeptName,addDepartmentDTO,deptParentId,deptReflex,token);
            } catch (Exception e) {
               log.error("syn user "+ user.getUsername()+"fail: "  +e.getMessage());
                continue;
            }
            //同步岗位数据
            try {
                jobId =  dealJobInfo(user,oaJobId,oaJobName,addJobDTO,jobReflex,token);
            } catch (Exception e) {
                log.error("syn user "+ user.getUsername()+"fail: "  +e.getMessage());
                continue;
            }
          // 同步账号数据
            try {
             accountId =  dealAccountInfo(user,jobId,token);
            } catch (Exception e) {
                log.error("syn user "+ user.getUsername()+"fail: "  +e.getMessage());
                continue;
            }
            //同步用户数据
            try {
                dealUserInfo(user,deptId,jobId,accountId,token);
            } catch (Exception e) {
                log.error("syn user "+ user.getUsername()+" fail: "  +e.getMessage());
            }
        }
    }



    /**
     * @Description: 获取集团级部门id
     * @Author: xgq
     * @Date: 2021/4/14 23:59
     * @param addDepartmentDTO :
     * @param token
     * @return: java.lang.String
     **/
    private String getGroupDeptId(AddDepartmentDTO addDepartmentDTO, String token) {
        String deptParentId = "";
        //查看是否有集团部门-----部门类型：0且父id是0，名称最好是万达集团，不是强制要求
        QueryDeptDTO queryDeptDTO = new QueryDeptDTO();
        queryDeptDTO.setParentId(BaseConstant.DEPT_TYPE_GROUP);
        queryDeptDTO.setType(BaseConstant.DEPT_TYPE_GROUP);
      ResponseResult  queryDeptResult =    synUserManage.queryDeptByCondition(queryDeptDTO,token);
        //错误，直接返回
        if(!BaseUtils.CheckResult(queryDeptResult)){
            throw new BusinessException("get group dept error:"+BaseUtils.getMsg(queryDeptResult) );
        }
         //查看是否存在
        JSONObject queryGroupDeptJson = BaseUtils.getContent(queryDeptResult);
        JSONArray groupDeptArray = queryGroupDeptJson.getJSONArray(BaseConstant.RESPONSE_RECORDS);
        if(null == groupDeptArray){
            throw new BusinessException("get group dept error: no " +BaseConstant.RESPONSE_RECORDS +"info...");
        }
          if(groupDeptArray.size()>0){
              deptParentId  =   groupDeptArray.getJSONObject(0).getString(BaseConstant.RESPONSE_ID);
          }  else {
              //不存在，创建顶级部门
              deptParentId = synUserManage.saveGroupDept(BaseConstant.DEPT_TYPE_GROUP, addDepartmentDTO, BaseConstant.DEPT_TYPE_GROUP,token);
          }
          if(StringUtils.isBlank(deptParentId)){
              throw new BusinessException("get group dept parent id error: id is black...");
          }
        return deptParentId;
    }

    /**
     * @Description: 处理部门数据
     * @Author: xgq
     * @Date: 2021/4/15 0:18
     * @param user :
     * @param oaDeptId :
     * @param oaDeptName :
     * @param addDepartmentDTO :
     * @param deptParentId
     * @param deptReflex :
     * @param token
     * @return: void
     **/
    private String dealDeptInfo(WdUser user, String oaDeptId, String oaDeptName, AddDepartmentDTO addDepartmentDTO,
                              String deptParentId, DeptReflex deptReflex,  String token) {
        String deptId = "";
        oaDeptId = user.getOrgID();
        oaDeptName =user.getOrgName();
        if(StringUtils.isBlank(oaDeptId)|| StringUtils.isBlank(oaDeptName)){
         //部门信息为空
            return deptId;
        }
        addDepartmentDTO.setName(oaDeptName);
        //上级部门id
        addDepartmentDTO.setParentId(deptParentId);
        //部门类型,0:集团; 1:公司; 2:部门,默认部门
        addDepartmentDTO.setType(BaseConstant.DEPT_TYPE_DEPT);
        //根据部门名称查找部门，判断部门名称是否存在，第一次同步应该不存在，走新建逻辑，再次同步时存在且映射正确
        //如果出现存在部门名称但是不存在映射的情况，一般为人为的添加了部门的数据，直接绑定对应的部门间关系
        QueryDeptDTO queryDeptDTO = new QueryDeptDTO();
            queryDeptDTO.setName(oaDeptName);
      ResponseResult queryDeptResult =   synUserManage.queryDeptByCondition(queryDeptDTO, token);
          if(!BaseUtils.CheckResult(queryDeptResult)){
              throw new BusinessException("query dept  error:"+BaseUtils.getMsg(queryDeptResult) );
          }
        JSONObject queryDeptJson = BaseUtils.getContent(queryDeptResult);
        JSONArray groupDeptArray = queryDeptJson.getJSONArray(BaseConstant.RESPONSE_RECORDS);
        ResponseResult result = null;
        //已经存在该部门名称
        if(null !=groupDeptArray && groupDeptArray.size()>0){
            //部门名称对应的现在的部门id
        String   newDeptId  =  groupDeptArray.getJSONObject(0).getString(BaseConstant.RESPONSE_ID);
         //查看有没有映射关系
            deptReflex =  deptReflexService.queryByCondition(oaDeptId);
            //没有，之前不存在，被人为创建的，直接创建部门间的映射关系 ，同时更新部门表的数据
            if(null ==deptReflex){
                deptReflex = new DeptReflex();
                deptReflex.setOaDeptId(oaDeptId);
                deptReflex.setDeptId(newDeptId);
                deptReflex.setId(BaseUtils.getUuid());
                boolean save = deptReflexService.save(deptReflex);
                if(!save){
                    throw new BusinessException("save dept reflex error...");
                }
                //更新那条部门表的数据
                addDepartmentDTO.setId(newDeptId);
                 result = synUserManage.updateDept(addDepartmentDTO, token);
              if(!BaseUtils.CheckResult(result)){
                  throw new BusinessException("update dept info error...");
                }
                deptId = newDeptId;
            }else {
          //已经存在映射关系，查看原来的部门id
                String oldDeptId = deptReflex.getDeptId();
           //正常应该是一致的，如果不一致，说明有人人为的修改了部门的名称信息
                 if(!newDeptId.equals(oldDeptId)){
                   //正常应该将原来的部门对应的部门名称改回去，但是因为部门名称已经存在，因为不确定改为什么，所以修改部门名称为：集团名称+部门名称
                     addDepartmentDTO.setId(oldDeptId);
                     addDepartmentDTO.setName(BaseConstant.GROUP_NAME+oaDeptName);
                     result =   synUserManage.updateDept(addDepartmentDTO,token);
                     if(!BaseUtils.CheckResult(result)){
                         throw new BusinessException("update dept info error...");
                     }
                 }
                                                  deptId = oldDeptId;
            }
        } else {
         //不存在该部门名称，查看有没有映射关系
            deptReflex =  deptReflexService.queryByCondition(oaDeptId);
            if(null == deptReflex){
                //没有映射关系，新数据，保存部门和映射关系
             deptId =   synUserManage.saveGroupDept(oaDeptId,addDepartmentDTO,BaseConstant.DEPT_TYPE_DEPT, token);
            } else {
             //已经存在映射关系，说明部门名称被修改了，更新部门数据
                String oldDeptId = deptReflex.getDeptId();
                addDepartmentDTO.setId(oldDeptId);
              result =    synUserManage.updateDept(addDepartmentDTO,token);
                if(!BaseUtils.CheckResult(result)){
                    throw new BusinessException("update dept info error...");
                }
                deptId = oldDeptId;
            }
        }
        return deptId;
    }

    /**
     * @Description: 处理岗位数据
     * @Author: xgq
     * @Date: 2021/4/15 0:36
     * @param user
     * @param oaJobId :
     * @param oaJobName :
     * @param addJobDTO :
     * @param jobReflex :
     * @param token
     * @return: void
     **/
    private String dealJobInfo(WdUser user, String oaJobId, String oaJobName, AddJobDTO addJobDTO, JobReflex jobReflex, String token) {
        String jobId = "";
        oaJobId = user.getJobId();
        oaJobName = user.getJobName();
        if(StringUtils.isBlank(oaJobId)|| StringUtils.isBlank(oaJobName)){
            //岗位信息为空
            return jobId;
        }
        addJobDTO.setAccountBelong(BaseConstant.ACCOUNT_TYPE_BUSINESS);
        addJobDTO.setGroupCode(BaseConstant.GROUP_CODE_WD);
        addJobDTO.setAccountId(BaseConstant.SYSTEM_ID);
        addJobDTO.setAppId(BaseConstant.APP_ID_PC);
        addJobDTO.setRoleType(BaseConstant.JOB_ROLE_TYPE);
        addJobDTO.setRoleName(oaJobName);
        ResponseResult result = new ResponseResult();
        //判断岗位名称是否存在,根据名称查询岗位列表
        QueryJobDTO queryJobDTO = new QueryJobDTO();
        BeanUtils.copyProperties(addJobDTO, queryJobDTO);
          JSONArray jobArray   = synUserManage.queryJobBuCondition(queryJobDTO,token);
          if(jobArray.size()> 0){
          //已经存在该岗位名称，查看岗位名称对应的岗位id
              String newJobId = jobArray.getJSONObject(0).getString(BaseConstant.RESPONSE_ID);
             //查看原岗位id有没有映射关系
              jobReflex = jobReflexService.queryByCondition(oaJobId);
              //没有，之前不存在，说明是别人创建的该岗位，创建岗位间的映射关系 ，同时更新这条岗位数据
              if(null ==jobReflex){
                  jobReflex = new JobReflex();
                  jobReflex.setOaJobId(oaJobId);
                  jobReflex.setJobId(newJobId);
                  jobReflex.setId(BaseUtils.getUuid());
                  boolean save = jobReflexService.save(jobReflex);
                  if(!save){
                      throw new BusinessException("save job reflex info error: "+BaseUtils.getMsg(result));
                  }
                  addJobDTO.setId(newJobId);
               result =   synUserManage.updateJob(addJobDTO,token);
                   if(!BaseUtils.CheckResult(result)){
                       throw new BusinessException("update job  info error: "+BaseUtils.getMsg(result));
                   }
                  jobId = newJobId;
              } else {
                  //已经存在映射关系，查看原来的岗位id
                  String oldJobId = jobReflex.getJobId();
                  //如果一致，说明是之前同步的，如果不一致，说明名称被改动过，更新原来岗位的岗位名称为：万达集团+岗位名称
                  if(!newJobId.equals(oldJobId)){
                      addJobDTO.setId(oldJobId);
                      addJobDTO.setRoleName(BaseConstant.GROUP_NAME+oaJobName);
                      result=   synUserManage.updateJob(addJobDTO,token);
                      if(!BaseUtils.CheckResult(result)){
                          throw new BusinessException("update job  info error: "+BaseUtils.getMsg(result));
                      }
                      jobId = oldJobId;
                  }
              }
          }else {
              //不存在该岗位名称，查看有没有映射关系
              jobReflex =  jobReflexService.queryByCondition(oaJobId);
              if(null == jobReflex){
                  //没有映射关系，新数据，保存岗位和岗位间的映射关系
                  jobReflex = new JobReflex();
                  jobReflex.setOaJobId(oaJobId);
                  jobId =   synUserManage.saveJob(addJobDTO,jobReflex,token);
              } else {
                  //已经存在映射关系，说明岗位名称被修改了，更新岗位数据
                  String oldJobId = jobReflex.getJobId();
                  addJobDTO.setId(oldJobId);
                  synUserManage.updateJob(addJobDTO,token);
                  jobId = oldJobId;
              }
          }
        return jobId;
    }

    /**
     * @Description: 同步账号数据
     * @Author: xgq
     * @Date: 2021/4/16 0:16
     * @param user :
     * @param jobId
     * @param token
     * @return: void
     **/
    private String dealAccountInfo(WdUser user, String jobId,  String token) {
        String accountId = "";
        //查询账号是否存在
        String username = user.getUsername();
        String employeeId = user.getEmployeeID();
        if(StringUtils.isBlank(username)|| StringUtils.isBlank(employeeId)){
            return accountId;
        }
        //查询账号名称是否存在
          JSONObject account = synUserManage.queryAccountByCondition(username,token);
          if(null == account){
              //不存在,创建账号信息和账号间映射关系信息
         accountId  =  synUserManage.saveAccountInfo(user,jobId,token);
          }else {
            //存在，查询映射关系表，看是否有对应的数据   获取账号id
              AccountReflex accountReflex = accountReflexService.queryByCondition(employeeId);
              if(null == accountReflex){
                //没有对应的数据，说明不是之前同步的，账号名称已经存在，不能够同步
                  throw new BusinessException(" account is exit...");
              } else {
               // 看是否对应
                  String oldAccountId = account.getString(BaseConstant.RESPONSE_ID);
                  //映射表存储的
                  String  relationAccountId = accountReflex.getAccountId();
                  //不一致，有问题
                  if(!oldAccountId.equals(relationAccountId)){
                      throw new BusinessException(" account info error...");
                  }
                 //一致，看是否需要更新--只有角色可能发生了变化,查询角色
                String oldRoleId =   synUserManage.queryRoleByAccount(oldAccountId,token);
                  if(oldRoleId==null) {
                     //更新账号信息
                      synUserManage.updateAccountInfo(oldAccountId,username,jobId,token);
                  }
                  if(!oldRoleId.equals(jobId)){
                      synUserManage.updateAccountInfo(oldAccountId,username,jobId,token);
                  }
                  accountId = oldAccountId;
              }
          }
        return accountId;
    }
    /**
     * @Description: 处理人员数据
     * @Author: xgq
     * @Date: 2021/4/15 1:00
     * @param user :
     * @param deptId :
     * @param jobId :
     * @param accountId
     * @param token
     * @return: void
     **/
    private void dealUserInfo(WdUser user, String deptId, String jobId, String accountId, String token) {
        if(StringUtils.isNotBlank(accountId)){
            //根据username查询人员信息
         JSONObject  userJson =    synUserManage.queryPersonByCondition(user,token);
            AddPersonDTO addPersonDTO = new AddPersonDTO();
            //判断是否存在
            if(null == userJson){
                //没有这个用户信息,保存用户信息
                synUserManage.savePerson(addPersonDTO, user,deptId,jobId,accountId,token);
            }else{
               //已经存在这个用户信息，获取账号信息，根据账号信息判断是之前存进去的，还是本来就存在这个账号
                String exitAccountId = userJson.getString(BaseConstant.ACCOUNT_ID);
                  //现在已经存在的账号跟要保存的账号不一致，说明不是同一个，也就是说之前已经存在，那么这个账号存不进去
             if(!accountId.equals(exitAccountId)){
                 throw new BusinessException(" account  is exit...");
             } else {
            // 之前自己存进去的，直接更新
                 //获取id
              String personId = userJson.getString(BaseConstant.RESPONSE_ID);
                 addPersonDTO.setId(personId);
                 synUserManage.savePerson(addPersonDTO,user,deptId,jobId,accountId, token);
             }
            }
        }
    }
}
