package com.persagy.sso.util;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.persagy.common.enums.ResponseCode;
import com.persagy.common.utils.ResponseResult;
import com.persagy.security.util.SecureAES;
import com.persagy.sso.config.ApplicationProperties;
import com.persagy.sso.constant.BaseConstant;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;

import java.util.Map;
import java.util.UUID;

/**
 * @ClassName : baseUtils
 * @Author ：xgq
 * @Date ：Created in 2021/4/15 18:53
 * @Description： 常用公共类
 * @Version : 1.0
 */
@Slf4j
public class BaseUtils {


     /**
      * @Description: 判断结果是否成功
      * @Author: xgq
      * @Date: 2021/4/15 20:08
      * @param responseResult:
      * @return: java.lang.Boolean
      **/
    public    static  Boolean CheckResult(ResponseResult  responseResult){
        String respCode = responseResult.getRespCode();
         if(StringUtils.isNotBlank(respCode)){
             if (ResponseCode.A00000.getCode().equals(respCode)) {
                 return true;
             }
         }
        return false;
    }

     /**
      * @Description: 获取返回content体,内容是JSONObject
      * @Author: xgq
      * @Date: 2021/4/15 20:44
      * @param responseResult:
      * @return: com.alibaba.fastjson.JSONObject
      **/
    public  static  JSONObject  getContent(ResponseResult  responseResult){
        Object content = responseResult.getContent();
        try {
          return  JSONObject.parseObject(JSON.toJSONString(content));
        } catch (Exception e) {
            log.error("convert error:"+e.getMessage());
            return  null;
        }
    }

    /**
     * @Description: 获取返回content体:内容是JSONArray
     * @Author: xgq
     * @Date: 2021/4/15 20:44
     * @param responseResult:
     * @return: com.alibaba.fastjson.JSONObject
     **/
    public  static JSONArray getContent2Array(ResponseResult  responseResult){
        Object content = responseResult.getContent();
        try {
            return JSONObject.parseArray(JSON.toJSONString(content));
        } catch (Exception e) {
            log.error("convert error:"+e.getMessage());
            return  null;
        }
    }

    /**
     * @Description: 获取返回content体:内容是String
     * @Author: xgq
     * @Date: 2021/4/16 9:59
     * @param responseResult:
     * @return: java.lang.String
     **/
    public  static String getContentStr(ResponseResult  responseResult){
        Object content = responseResult.getContent();
        try {
            String result = (String) content;
            return result;
        } catch (Exception e) {
            log.error("convert error:"+e.getMessage());
            return  null;
        }
    }

    /**
     * @Description: 获取返回的msg信息
     * @Author: xgq
     * @Date: 2021/4/15 20:45
     * @param responseResult:
     * @return: java.lang.String
     **/
    public  static  String  getMsg(ResponseResult  responseResult){
        return responseResult.getRespMsg();
    }

   /**
    * @Description: 获取uuid
    * @Author: xgq
    * @Date: 2021/4/15 23:01

    * @return: java.lang.String
    **/
    public static  String getUuid(){
     return    UUID.randomUUID().toString().replaceAll("-", "");
    }
}
